@@ -2,11 +2,12 @@ from math import ceil, floor
 import os
 from pathlib import Path
 import re
-from typing import Union, List
+from typing import Union, List, Sequence
 import warnings
 
 import numpy as np
-import scipy as sp
+import scipy
+import scipy.sparse
 from scipy.spatial.distance import cdist
 
 import mne
@@ -128,22 +129,25 @@ def _vertices_equal(v1, v0):
     return np.array_equal(v1[0], v0[0]) and np.array_equal(v1[1], v0[1])
 
 
-def shift_mne_epoch_trigger(epochs, trigger_shift, min_shift=None, max_shift=None):
+def shift_mne_epoch_trigger(
+        epochs: mne.BaseEpochs,
+        trigger_shift: Sequence[float],
+        min_shift: float = None,
+        max_shift: float = None,
+):
     """Shift the trigger in an MNE Epochs object
 
     Parameters
     ----------
-    epochs : mne.Epochs
+    epochs
         Epochs object.
-    trigger_shift : scalar sequence
+    trigger_shift
         For each event in ``epochs`` the amount of time by which to shift the
         trigger (in seconds).
-    min_shift : scalar (optional)
-        Minimum time shift, used to crop data (default is
-        ``min(trigger_shift)``).
-    max_shift : scalar (optional)
-        Maximum time shift, used to crop data (default is
-        ``max(trigger_shift)``).
+    min_shift
+        Minimum time shift, used to crop data (default is ``min(trigger_shift)``).
+    max_shift
+        Maximum time shift, used to crop data (default is ``max(trigger_shift)``).
 
     Returns
     -------
@@ -161,20 +165,16 @@ def shift_mne_epoch_trigger(epochs, trigger_shift, min_shift=None, max_shift=Non
     else:
         min_shift = int(floor(min_shift / tstep))
         if any(shift < min_shift for shift in shifts):
-            invalid = (i for i, shift in enumerate(shifts) if shift < min_shift)
-            raise ValueError("The post_baseline_trigger_shift is smaller than "
-                             "min_shift at the following events %s" %
-                             ', '.join(map(str, invalid)))
+            invalid = ', '.join([str(i) for i, shift in enumerate(shifts) if shift < min_shift])
+            raise ValueError(f"The post_baseline_trigger_shift is smaller than min_shift at the following events {invalid}")
 
     if max_shift is None:
         max_shift = max(shifts)
     else:
         max_shift = int(ceil(max_shift / tstep))
         if any(shift > max_shift for shift in shifts):
-            invalid = (i for i, shift in enumerate(shifts) if shift > max_shift)
-            raise ValueError("The post_baseline_trigger_shift is greater than "
-                             "max_shift at the following events %s" %
-                             ', '.join(map(str, invalid)))
+            invalid = ', '.join([str(i) for i, shift in enumerate(shifts) if shift > max_shift])
+            raise ValueError(f"The post_baseline_trigger_shift is greater than max_shift at the following events {invalid}")
 
     x, y, z = data.shape
     start_offset = -min_shift
@@ -189,9 +189,10 @@ def shift_mne_epoch_trigger(epochs, trigger_shift, min_shift=None, max_shift=Non
     events = epochs.events.copy()
     events[:, 0] += shifts
 
+    info = mne.Info(projs={}, **{k: v for k, v in epochs.info.items() if k != 'projs'})
     with warnings.catch_warnings():
-        warnings.filterwarnings('ignore', 'The events passed to the Epochs constructor', RuntimeWarning)
-        return mne.EpochsArray(new_data, epochs.info, events, tmin, epochs.event_id)
+        warnings.filterwarnings('ignore', 'The events passed to the Epochs constructor are not chronologically ordered', RuntimeWarning)
+        return mne.EpochsArray(new_data, info, events, tmin, epochs.event_id)
 
 
 def label_from_annot(sss, subject, subjects_dir, parc=None, color=(0, 0, 0)):
@@ -387,7 +388,7 @@ def morph_source_space(
         data: Union[NDVar, SourceSpace],
         subject_to: str = None,
         vertices_to: Union[List, str] = None,
-        morph_mat: sp.sparse.spmatrix = None,
+        morph_mat: scipy.sparse.spmatrix = None,
         copy: bool = False,
         parc: Union[bool, str] = True,
         xhemi: bool = False,
@@ -576,7 +577,7 @@ def morph_source_space(
         with warnings.catch_warnings():
             warnings.filterwarnings('ignore', r'\d+/\d+ vertices not included in smoothing', module='mne')
             morph_mat = compute_morph_matrix(subject_from, subject_to, source.vertices, source_to.vertices, None, subjects_dir, xhemi=xhemi)
-    elif not sp.sparse.issparse(morph_mat):
+    elif not scipy.sparse.issparse(morph_mat):
         raise ValueError('morph_mat must be a sparse matrix')
     elif not sum(len(v) for v in source_to.vertices) == morph_mat.shape[0]:
         raise ValueError('morph_mat.shape[0] must match number of vertices in vertices_to')
