@@ -410,36 +410,46 @@ def cross_correlation(in1, in2, name=None):
     return NDVar(x_corr, (time,), *op_name(in1, '*', in2, merge_info((in1, in2)), name))
 
 
-def cwt_morlet(y, freqs, use_fft=True, n_cycles=3.0, zero_mean=False,
-               out='magnitude', decim=1):
+def cwt_morlet(
+        y: NDVar,
+        frequencies: Union[Sequence[float], float],
+        use_fft: bool = True,
+        n_cycles: Union[float, Sequence[float]] = 3.0,
+        zero_mean: bool = True,
+        output: Literal['complex', 'power', 'phase', 'magnitude'] = 'magnitude',
+        decim: int = 1,
+) -> NDVar:
     """Time frequency decomposition with Morlet wavelets (mne-python)
 
     Parameters
     ----------
-    y : NDVar with time dimension
-        Signal.
-    freqs : scalar | array
-        Frequency/ies of interest. For a scalar, the output will not contain a
+    y
+        Input signal.
+    frequencies
+        Frequencies of interest. For a scalar, the output will not contain a
         frequency dimension.
-    use_fft : bool
+    use_fft
         Compute convolution with FFT or temporal convolution.
-    n_cycles: float | array of float
+    n_cycles
         Number of cycles. Fixed number or one per frequency.
-    zero_mean : bool
+    zero_mean
         Make sure the wavelets are zero mean.
-    out : 'complex' | 'magnitude'
-        Format of the data in the returned NDVar.
+    output
+        Format of the data in the returned NDVar. Default is the complex wavelet
+        transform.
+    decim
+        Decimate the time axis by this factor.
 
     Returns
     -------
-    tfr : NDVar
+    tfr
         Time frequency decompositions.
     """
-    if out == 'magnitude':
+    if output == 'magnitude':
         magnitude_out = True
-        out = 'power'
-    elif out not in ('complex', 'phase', 'power'):
-        raise ValueError("out=%r" % (out,))
+        output = 'complex'
+    elif output not in ('complex', 'phase', 'power'):
+        raise ValueError(f"{output=}")
     else:
         magnitude_out = False
     dimnames = y.get_dimnames(last='time')
@@ -449,15 +459,14 @@ def cwt_morlet(y, freqs, use_fft=True, n_cycles=3.0, zero_mean=False,
     data_flat = data.reshape((1, shape_outer, data.shape[-1]))
     time_dim = dims[-1]
     sfreq = 1. / time_dim.tstep
-    if np.isscalar(freqs):
-        freqs = [freqs]
+    if np.isscalar(frequencies):
+        frequencies = [frequencies]
         fdim = None
     else:
-        fdim = Scalar("frequency", freqs, 'Hz')
-        freqs = fdim.values
+        fdim = Scalar("frequency", frequencies, 'Hz')
+        frequencies = fdim.values
 
-    x_flat = mne.time_frequency.tfr_array_morlet(
-        data_flat, sfreq, freqs, n_cycles, zero_mean, use_fft, decim, out)
+    x_flat: np.ndarray = mne.time_frequency.tfr_array_morlet(data_flat, sfreq, frequencies, n_cycles, zero_mean, use_fft, decim, output)
 
     out_shape = list(data.shape)
     out_dims = list(dims)
@@ -470,7 +479,7 @@ def cwt_morlet(y, freqs, use_fft=True, n_cycles=3.0, zero_mean=False,
         out_dims[-1] = UTS(time_dim.tmin, time_dim.tstep * decim, n_times)
     x = x_flat.reshape(out_shape)
     if magnitude_out:
-        x **= 0.5
+        x = abs(x)
     info = _info.default_info('A', y.info)
     return NDVar(x, out_dims, y.name, info)
 
@@ -642,7 +651,7 @@ def find_peaks(ndvar):
         NDVar that is ``True`` at local maxima.
     """
     for custom_ax, dim in enumerate(ndvar.dims):
-        if getattr(dim, '_connectivity_type', None) == 'custom':
+        if dim._connectivity_type == 'custom':
             break
     else:
         custom_ax = 0
@@ -840,6 +849,7 @@ def neighbor_correlation(
         dim: str = 'sensor',
         obs: str = 'time',
         func: Callable = np.mean,
+        flat: float = 0,
         name: str = None,
 ) -> NDVar:
     """Calculate Neighbor correlation
@@ -854,9 +864,11 @@ def neighbor_correlation(
         Dimension which provides observations over which to compute the
         correlation (default 'time').
     func
-        Numpy function to summarize the neighbors. Default :fun:`numpy.mean`;
-        for example, use :fun:`numpy.max` to test whether any neighbor is
+        Numpy function to summarize the neighbors. Default :func:`numpy.mean`;
+        for example, use :func:`numpy.max` to test whether any neighbor is
         correlated.
+    flat
+        Value to substitute for flat channels (default 0).
     name
         Name for the new NDVar.
 
@@ -867,30 +879,32 @@ def neighbor_correlation(
         correlation coefficient with its neighbors.
     """
     x = asndvar(x)
-    low_var = x.std(obs).x < 1e-25
+    is_flat = x.std(obs).x < 1e-25
     dim_obj = x.get_dim(dim)
-    if numpy.any(low_var):
-        raise ValueError(f"Low variance at {dim} = {dim_obj._dim_index(low_var)}")
     if name is None:
         name = x.name
 
     # find neighbors
     neighbors = defaultdict(list)
     for a, b in dim_obj.connectivity():
+        if is_flat[a] or is_flat[b]:
+            continue
         neighbors[a].append(b)
         neighbors[b].append(a)
 
     # for each point, find the average correlation with its neighbors
     data = x.get_data((dim, obs))
     cc = numpy.corrcoef(data)
-    try:
-        y = numpy.array([func(cc[i, neighbors[i]]) for i in range(len(dim_obj))])
-    except ValueError:
-        if any(len(ns) == 0 for ns in neighbors.values()):
+    ncs = numpy.zeros(len(dim_obj))
+    for i in range(len(ncs)):
+        if is_flat[i]:
+            ncs[i] = flat
+        elif i not in neighbors:
             raise ValueError(f"Some elements do not have any neighbors")
-        raise
+        else:
+            ncs[i] = func(cc[i, neighbors[i]])
     info = _info.for_stat_map('r', old=x.info)
-    return NDVar(y, (dim_obj,), name, info)
+    return NDVar(ncs, (dim_obj,), name, info)
 
 
 def normalize_in_cells(
@@ -1288,6 +1302,53 @@ def segment(continuous, times, tstart, tstop, decim=1):
                  continuous.info.copy(), continuous.name)
 
 
+def set_connectivity(
+        data: Union[NDVar, Dimension],
+        dim: str = None,
+        connectivity: Union[str, Sequence] = 'none',
+        name: str = None,
+):
+    """Change the connectivity of an NDVar or a Dimension
+
+    Parameters
+    ----------
+    data
+        NDVar for which to change the connectivity.
+    dim
+        Dimension for which to set the connectivity.
+    connectivity
+        Connectivity between elements. Set to ``"none"`` for no connections or
+        ``"grid"`` to use adjacency in the sequence of elements as connection.
+        Set to :class:`numpy.ndarray` to specify custom connectivity. The array
+        should be of shape (n_edges, 2), and each row should specify one
+        connection [i, j] with i < j, with rows sorted in ascending order. If
+        the array's dtype is uint32, property checks are disabled to improve
+        efficiency.
+    name
+        Name for the new NDVar (default is ``data.name``).
+
+    Returns
+    -------
+    data_with_connectivity
+        Shallow copy of ``data`` with the new connectivity.
+    """
+    if isinstance(data, NDVar):
+        dimension = data.get_dim(dim)
+    elif isinstance(data, Dimension):
+        data, dimension = None, data
+    else:
+        raise TypeError(f"{data=}")
+    new = copy(dimension)
+    new._connectivity_type, new._connectivity = dimension._connectivity_arg(connectivity)
+    if data is None:
+        return new
+    if name is None:
+        name = data.name
+    axis = data.get_axis(dim)
+    dims = (*data.dims[:axis], new, *data.dims[axis + 1:])
+    return NDVar(data.x, dims, name, data.info)
+
+
 def set_parc(
         data: Union[NDVar, SourceSpace],
         parc: Union[str, Factor],
