@@ -14,7 +14,7 @@ from scipy.linalg import lstsq
 import scipy.stats
 
 from .. import fmtxt
-from .._utils import LazyProperty
+from functools import cached_property
 from .._data_obj import (
     ModelArg, IndexArg, VarArg,
     Dataset, Model, asmodel, assub, asvar, assert_has_no_empty_cells, find_factors,
@@ -249,15 +249,15 @@ class LM:
 
         return table
 
-    @LazyProperty
+    @cached_property
     def F(self):
         return self.MS_model / self.MS_res
 
-    @LazyProperty
+    @cached_property
     def p(self):
         return scipy.stats.distributions.f.sf(self.F, self.df_model, self.df_res)
 
-    @LazyProperty
+    @cached_property
     def regression_table(self):
         """
         Not fully implemented!
@@ -293,7 +293,7 @@ class LM:
                 table.empty_row()
         return table
 
-    @LazyProperty
+    @cached_property
     def residuals(self):
         return self.y.x - np.dot(self._p.x, self.beta)
 
@@ -438,18 +438,14 @@ class _BalancedFixedNDANOVA(_BalancedNDANOVA):
     "For balanced but not fully specified models"
     def __init__(self, x):
         if x.df_error <= 0:
-            raise ValueError("Model %s is overspecified with df_error=%s. "
-                             "Alle effects are fixed, should one be random?" %
-                             (x.name, x.df_error))
+            raise ValueError(f"Model {x.name} is overspecified with df_error={x.df_error}; all effects are fixed, should one be random?")
         effects = x.effects
         dfs_denom = (x.df_error,) * len(effects)
         _BalancedNDANOVA.__init__(self, x, effects, dfs_denom)
-
         self.df_error = x.df_error
 
     def _map_balanced(self, y, flat_f_map, x_full, xsinv):
-        anova_fmaps(y, x_full, xsinv, flat_f_map, self._effect_to_beta,
-                    self.df_error)
+        anova_fmaps(y, x_full, xsinv, flat_f_map, self._effect_to_beta, self.df_error)
 
 
 class _BalancedMixedNDANOVA(_BalancedNDANOVA):
@@ -783,17 +779,17 @@ class ANOVA:
 
     Parameters
     ----------
-    y : Var
+    y
         dependent variable
-    x : Model
+    x
         Model to fit to y
-    sub : index
+    sub
         Only use part of the data.
-    ds : Dataset
+    ds
         Dataset to use data from.
-    title : str | FMText
+    title
         Title for the results table.
-    caption : str | FMText
+    caption
         Caption for the results table.
 
     Attributes
