@@ -16,7 +16,7 @@ from .._data_obj import (
     combine,
     cellname, dataobj_repr, nice_label,
 )
-from .._utils import LazyProperty
+from functools import cached_property
 from .permutation import resample
 from . import stats
 
@@ -68,6 +68,8 @@ class Correlation:
     df : int
         Degrees of freedom.
     """
+    _statistic = 'r'
+
     def __init__(
             self,
             y: NumericArg,
@@ -93,21 +95,55 @@ class Correlation:
                 raise ValueError(f"Shape mismatch: y.shape={y.shape}, x.shape={x.shape}")
             x_y = y.ravel()
             x_x = x.ravel()
-        self.r, self.p, self.df = _corr(x_y, x_x)
+        self.r, self.p, self.df = self._corr(x_y, x_x)
         self._y = dataobj_repr(y)
         self._x = dataobj_repr(x)
 
+    def _corr(self, y: np.ndarray, x: np.ndarray):
+        return _corr(y, x)
+
     def __repr__(self):
-        return f"<Correlation: {self._y} ~ {self._x}; {self._asfmtext()}> "
+        return f"<{self.__class__.__name__}: {self._y} ~ {self._x}; {self._asfmtext()}> "
 
     def _asfmtext(self, **_):
-        return fmtxt.FMText([fmtxt.eq('r', self.r, self.df), ', ', fmtxt.peq(self.p)])
+        return fmtxt.FMText([fmtxt.eq(self._statistic, self.r, self.df), ', ', fmtxt.peq(self.p)])
 
     @property
     def stars(self):
         return fmtxt.Stars.from_p(self.p)
 
 
+class RankCorrelation(Correlation):
+    """Spearman rank correlation between y and x
+
+    Parameters
+    ----------
+    y : Var | NDVar
+        First variable.
+    x : Var | NDVar
+        Second variable. Needs to have same type/shape as ``y``.
+    sub : index
+        Use only a subset of the data
+    ds : Dataset
+        If a Dataset is given, all data-objects can be specified as names of
+        Dataset variables.
+
+    Attributes
+    ----------
+    r : float
+        Spearman rank correlation coefficient.
+    p : float
+        Two-tailed p-value.
+    """
+
+    def _corr(self, y: np.ndarray, x: np.ndarray):
+        r, p = scipy.stats.spearmanr(y, x)
+        return r, p, None
+
+    def _asfmtext(self, **_):
+        return fmtxt.FMText([fmtxt.eq(self._statistic, self.r), ', ', fmtxt.peq(self.p)])
+
+
 def lilliefors(data, formatted=False, **kwargs):
     """Lilliefors' test for normal distribution
 
@@ -546,13 +582,17 @@ def ttest(y, x=None, against=0, match=None, sub=None, corr='Hochberg',
 
 
 class TTest:
+    _statistic = 't'
 
-    def __init__(self, difference, t, df, tail):
+    def __init__(self, difference, t, df, tail, std=None):
         self._difference = difference
         self.t = t
         self.df = df
         self.p = stats.ttest_p(self.t, self.df, tail)
         self.tail = tail
+        # effect-size
+        if std is not None:
+            self.d = difference / std
 
     @property
     def stars(self):
@@ -605,6 +645,8 @@ class TTestOneSample(TTest):
         Tailedness of the p value.
     df : int
         Degrees of freedom.
+    d : float
+        Cohen's *d*.
     full : FMText
         Full description of the test result.
     """
@@ -630,13 +672,13 @@ class TTestOneSample(TTest):
         if popmean:
             v = v - popmean
         t = stats.t_1samp(v)[0]
-        TTest.__init__(self, v.mean(), t, n - 1, tail)
+        TTest.__init__(self, v.mean(), t, n - 1, tail, ct.y.std(ddof=1))
 
     def __repr__(self):
         cmp = '=><'[self.tail]
         return f"<{self.__class__.__name__}: {self._y_name} {cmp} {self.popmean}; {self._asfmtext(difference=True)}>"
 
-    @LazyProperty
+    @cached_property
     def full(self):
         return fmtxt.FMText([fmtxt.eq('M', self.mean), ', ', fmtxt.eq('SD', self._y.std()), ', ', self._asfmtext()])
 
@@ -727,7 +769,7 @@ class TTestIndependent(TTest):
             desc = f"{self._y} ~ {self._x}, {self.c1_name} {cmp} {self.c0_name}"
         return f"<{self.__class__.__name__}: {desc}; {self._asfmtext(difference=True)}>"
 
-    @LazyProperty
+    @cached_property
     def full(self):
         return fmtxt.FMText([
             self.c1_name, ': ', fmtxt.eq('M', self._y1.mean()), ', ', fmtxt.eq('SD', self._y1.std()), '; ',
@@ -792,6 +834,8 @@ class MannWhitneyU:
     -----
     Based on :func:`scipy.stats.mannwhitneyu`.
     """
+    _statistic = 'U'
+
     def __init__(
             self,
             y: VarArg,
@@ -893,6 +937,8 @@ class TTestRelated(TTest):
         Mean of condition ``c1``.
     c0_mean : float
         Mean of condition ``c0``.
+    d : float
+        Cohen's *d*.
     full : FMText
         Full description of the test result.
 
@@ -924,7 +970,7 @@ class TTestRelated(TTest):
         self.c0_mean = y0.mean()
         self.difference = y1 - y0
         t = stats.t_1samp(self.difference.x[:, None])[0]
-        TTest.__init__(self, self.difference.x.mean(), t, n - 1, tail)
+        TTest.__init__(self, self.difference.x.mean(), t, n - 1, tail, self.difference.std(ddof=1))
         self._match = dataobj_repr(match, True)
 
     def __repr__(self):
@@ -935,7 +981,7 @@ class TTestRelated(TTest):
             desc = f"{self._y} ~ {self._x}, {self._c1} {cmp} {self._c0}"
         return f"<{self.__class__.__name__}: {desc}; {self._asfmtext(difference=True)}>"
 
-    @LazyProperty
+    @cached_property
     def full(self):
         return fmtxt.FMText([
             self.c1_name, ': ', fmtxt.eq('M', self.c1_mean), '; ',
@@ -1011,6 +1057,8 @@ class WilcoxonSignedRank:
     -----
     Based on :func:`scipy.stats.wilcoxon`.
     """
+    _statistic = 'W'
+
     def __init__(
             self,
             y: VarArg,
@@ -1397,7 +1445,7 @@ def correlations(y, x, cat=None, sub=None, ds=None, asds=False):
     return table
 
 
-def _corr(y, x):
+def _corr(y: np.ndarray, x: np.ndarray):
     n = len(y)
     assert len(x) == n
     df = n - 2
